@@ -3,9 +3,9 @@
 # 提取数据
 import re
 import sys,os
-from mobs.utils.loadUtils import FileUtils
-
-
+from mobs.utils.loadUtils import FileUtils, Config
+from loguru import logger
+from mobs.utils.takes import execute_time
 from typing import Tuple, Dict, Union, Text, List, Callable
 
 pattern = {
@@ -16,6 +16,45 @@ pattern = {
 
 
 class ExtractUtils(object):
+    config =  Config
+
+    @execute_time
+    def extract_zh_cn(self, args: Union[Text, List]) -> List:
+        '''
+        extract list or str >>> zh_CN
+        :param args:
+        :return:
+        '''
+
+        pattern = self.config.get_yaml_conf()
+        zhe_cn: List = []
+        if not isinstance(args, (str, list)):
+            return zhe_cn
+        elif isinstance(args, list):
+            zhe_cn = [re.compile(pattern).findall(x) for x in args]
+        elif isinstance(args, str):
+            zhe_cn = re.compile(pattern).findall(args)
+        logger.info(zhe_cn)
+        return zhe_cn
+
+    @execute_time
+    def extract_zh_cn_rt(self, args: Union[Text, List]) -> List:
+        '''
+        extract list or str >>> zh_CN
+        :param args:
+        :return:
+        '''
+
+        pattern = r'[\u4e00-\u9fa5]+'
+        zhe_cn: List = []
+        if not isinstance(args, (str, list)):
+            return zhe_cn
+        elif isinstance(args, list):
+            zhe_cn = [re.compile(pattern).findall(x) for x in args]
+        elif isinstance(args, str):
+            zhe_cn = re.compile(pattern).findall(args)
+        logger.info(zhe_cn)
+        return zhe_cn
 
     @staticmethod
     def extract_content_in_brackets(data: Text) -> List:
@@ -105,7 +144,13 @@ class ExtractUtils(object):
         return list_content
 
 if __name__ == '__main__':
-    path = r"D:\CodeBase\mobs\test\test_data\test_01.txt"
-    a = ExtractUtils.operate_pra('id', path)
-    print(a)
+    path = r"test\test_data\test_01.txt"
+
+
+    b = ExtractUtils()
+    #print(b.extract_content_in_brackets("你好！(今天)有(空)吗?"))
+    temp = b.extract_zh_cn(['你好sdfs十多分88吗?','asd','安定4','asd安定'])
+    temp2 = b.extract_zh_cn_rt(['你好sdfs十多分88吗?', 'asd', '安定4', 'asd安定'])
+    print(temp)
+    print(temp2)
 
